# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk_test.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sdk_test.proto',
  package='forge_abi',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0esdk_test.proto\x12\tforge_abi\x1a\x19google/protobuf/any.proto\"(\n\x0bpythonSDKTx\x12\n\n\x02to\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\rb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_PYTHONSDKTX = _descriptor.Descriptor(
  name='pythonSDKTx',
  full_name='forge_abi.pythonSDKTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='to', full_name='forge_abi.pythonSDKTx.to', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='forge_abi.pythonSDKTx.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=96,
)

DESCRIPTOR.message_types_by_name['pythonSDKTx'] = _PYTHONSDKTX
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

pythonSDKTx = _reflection.GeneratedProtocolMessageType('pythonSDKTx', (_message.Message,), dict(
  DESCRIPTOR = _PYTHONSDKTX,
  __module__ = 'sdk_test_pb2'
  # @@protoc_insertion_point(class_scope:forge_abi.pythonSDKTx)
  ))
_sym_db.RegisterMessage(pythonSDKTx)


# @@protoc_insertion_point(module_scope)
