{% extends "layout.html" %}
{% block content %}
    <section class="hero">
        <section class="session">
            <br>
            <br>
            <section class="hero is-white">
                <div class="hero-body">
                    <div class="container has-text-centered">
                        <h1 class="title">Ticket Details</h1>
                    </div>
                </div>
            </section>
            <br>
            <br>
            <section class="section">
                <section class="container">
                    <div class="columns">
                <div class="column">
                    <div class="card">
                        <div class="card-content">
                            <div class="media">
                                <div class="media-left">
                                    <figure class="image" style="height: 50px; width: 50px;"><img
                                            src="https://source.unsplash.com/random/96x96" alt="Image"></figure>
                                </div>
                                <div class="media-content">
                                    <p class="title is-4">{{ event.event_info.title }}</p>
                                    <p class="subtitle is-6">Location: {{ event.event_info.location }}</p>
                                    <p class="subtitle is-6">Start: {{ event.display_start_time }}</p>
                                    <p class="subtitle is-6">End: {{ event.display_end_time }}</p>
                                </div>
                            </div>
                            <div class="content">
                                <p>{{ event.event_info.description }} </p>
                                <br>
                                {% if ticket.transferrable == True and view_only==False %}
                                <a class="button is-link"
                                   href={{ url_for('use',address=ticket.address) }}> Use Ticket</a>
                                {% else %}
                                {% endif %}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
                </section>
            </section>
        </section>
    </section>
{% endblock %}
